package com.cultural.heritage.model.dto.order;

import com.cultural.heritage.model.dto.snapshot.AddressSnapshot;
import com.cultural.heritage.model.dto.snapshot.ContactsSnapshot;
import com.cultural.heritage.model.dto.snapshot.CouponSnapshot;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

@Data
@Schema(description = "订单添加请求体", requiredProperties = {"userId", "addressSnapshot", "contactsSnapshot",
"couponSnapshot", "totalAmount", "orderStatus", "orderItemList"})
public class OrderAddRequest implements Serializable {


    /**
     * 订单类别
     */
    @Schema(description = "订单类别", example = "product")
    private String orderType;


    /**
     * 用户昵称
     */
    @Schema(description = "用户昵称", example = "张三")
    private String userName;


    /**
     * 地址信息快照
     */
    @Schema(description = "订单地址信息")
    private AddressSnapshot addressSnapshot;


    /**
     * 联系人信息快照
     */
    @Schema(description = "订单联系人信息")
    private ContactsSnapshot contactsSnapshot;


    /**
     * 优惠券信息快照
     */
    @Schema(description = "订单优惠券信息")
    private CouponSnapshot couponSnapshot;


    /**
     * 订单总金额
     */
    @Schema(description = "订单总金额", example = "500")
    private BigDecimal totalAmount;

    /**
     * 订单状态
     */
    @Schema(description = "订单状态", example = "待发货")
    private String orderStatus;

    /**
     * 订单备注
     */
    private String note;

    /**
     * 订单明细信息
     */
    @Schema(description = "订单明细信息")
    private List<OrderItemAddRequest> orderItemList;



    @Serial
    private static final long serialVersionUID = 1L;
}
